<?php
/**
 * wisu functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package WordPress
 * @subpackage WiSu
 * @since WiSu 1.0
 */

// This theme requires WordPress 5.3 or later.
if (version_compare($GLOBALS['wp_version'], '5.3', '<')) {
    require get_template_directory() . '/inc/back-compat.php';
}

if (!function_exists('hs_wisu_setup')) :
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function hs_wisu_setup()
    {
        /*
         * Make theme available for translation.
         * Translations can be filed in the /languages/ directory.
         * If you're building a theme based on wisu, use a find and replace
         * to change 'wisu' to the name of your theme in all the template files.
         */
        load_theme_textdomain('wisu', get_template_directory() . '/languages');

        // Add default posts and comments RSS feed links to head.
        add_theme_support('automatic-feed-links');

        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support('title-tag');

        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support('post-thumbnails');
        add_image_size('wisu-large', 1200, 606, true);
        add_image_size('wisu-medium', 800, 600, true);

        // This theme uses wp_nav_menu() in three location.
        register_nav_menus(
            array(
                'main-menu' => esc_html__('Main Menu', 'wisu'),
                'social-menu' => esc_html__('Social Menu', 'wisu'),
            )
        );

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support(
            'html5',
            array(
                'search-form',
                'comment-form',
                'comment-list',
                'gallery',
                'caption',
                'style',
                'script',
                'navigation-widgets',
            )
        );

        // Set up the WordPress core custom header feature.
        $defaults = array(
            'default-image' => '',
            'default-text-color' => '333',
            'width' => 1170,
            'height' => 400,
            'flex-width' => true,
            'flex-height' => true,
        );
        add_theme_support('custom-header', $defaults);

        // Set up the WordPress core custom background feature.
        add_theme_support(
            'custom-background',
            apply_filters(
                'wisu_custom_background_args',
                array(
                    'default-color' => 'ffffff',
                    'default-image' => '',
                )
            )
        );

        // Add theme support for selective refresh for widgets.
        add_theme_support('customize-selective-refresh-widgets');

        // Add support for responsive embedded content.
        add_theme_support('responsive-embeds');

        // Add support for default block styles.
        add_theme_support('wp-block-styles');

        // Add support for full and wide align images.
        add_theme_support('align-wide');

        // Add support for custom line height controls.
        add_theme_support('custom-line-height');

        // Add support for experimental link color control.
        add_theme_support('experimental-link-color');

        // Add support for experimental cover block spacing.
        add_theme_support('custom-spacing');

        // Add support for custom units.
        // This was removed in WordPress 5.6 but is still required to properly support WP 5.5.
        add_theme_support('custom-units');

        // Add support for editor styles.
        add_theme_support('editor-styles');

        // Enqueue editor styles.
        add_editor_style('assets/css/wisu-editor-style.css');

        /*
         * Add support custom font sizes.
         *
         * Add the line below to disable the custom color picker in the editor.
         * add_theme_support( 'disable-custom-font-sizes' );
         */
        add_theme_support(
            'editor-font-sizes',
            array(
                array(
                    'name' => __('Small', 'wisu'),
                    'shortName' => __('S', 'wisu'),
                    'size' => 16,
                    'slug' => 'small',
                ),
                array(
                    'name' => __('Medium', 'wisu'),
                    'shortName' => __('M', 'wisu'),
                    'size' => 20,
                    'slug' => 'medium',
                ),
                array(
                    'name' => __('Large', 'wisu'),
                    'shortName' => __('L', 'wisu'),
                    'size' => 25,
                    'slug' => 'large',
                ),
                array(
                    'name' => __('Larger', 'wisu'),
                    'shortName' => __('XL', 'wisu'),
                    'size' => 35,
                    'slug' => 'larger',
                ),
            )
        );

        // Editor color palette.
        add_theme_support(
            'editor-color-palette',
            array(
                array(
                    'name' => esc_html__('Theme Color', 'wisu'),
                    'slug' => 'theme-color',
                    'color' => '#f47742',
                ),
                array(
                    'name' => esc_html__('Theme Text Color', 'wisu'),
                    'slug' => 'theme-text-color',
                    'color' => '#666',
                ),
                array(
                    'name' => esc_html__('Theme Header Color', 'wisu'),
                    'slug' => 'theme-header-color',
                    'color' => '#333',
                ),
            )
        );

        /**
         * Add support for core custom logo.
         *
         * @link https://codex.wordpress.org/Theme_Logo
         */
        add_theme_support(
            'custom-logo',
            array(
                'height' => 300,
                'width' => 250,
                'flex-width' => true,
                'flex-height' => true,
                'unlink-homepage-logo' => true,
            )
        );
    }
endif;
add_action('after_setup_theme', 'hs_wisu_setup');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function hs_wisu_content_width()
{
    $GLOBALS['content_width'] = apply_filters('wisu_content_width', 640);
}

add_action('after_setup_theme', 'hs_wisu_content_width', 0);

/**
 * Enqueue scripts and styles.
 */
if (!function_exists('hs_wisu_enqueue_scripts')) {
    function hs_wisu_enqueue_scripts()
    {
        // Theme stylesheet.
        wp_enqueue_style('wisu-style', get_stylesheet_uri());
        global $wp_scripts;
        wp_enqueue_style('wisu-font-awesome', esc_url(get_template_directory_uri() . '/assets/fonts/font-awesome/css/font-awesome.min.css'), array('wisu-style'), null);
        wp_enqueue_script('wisu-main-script', get_template_directory_uri() . '/assets/js/wisu.js', array(), '1.0.0', true);
        if (is_singular() && comments_open() && get_option('thread_comments')) {
            wp_enqueue_script('comment-reply');
        }

        // Register the IE11 polyfill loader.
        wp_register_script(
            'hs-wisu-ie11-polyfills',
            null,
            array(),
            wp_get_theme()->get('Version'),
            true
        );
        wp_add_inline_script(
            'hs-wisu-ie11-polyfills',
            wp_get_script_polyfill(
                $wp_scripts,
                array(
                    'Element.prototype.matches && Element.prototype.closest && window.NodeList && NodeList.prototype.forEach' => 'hs-wisu-ie11-polyfills-asset',
                )
            )
        );
    }

    add_action('wp_enqueue_scripts', 'hs_wisu_enqueue_scripts');
}

function hs_wisu_custom_add_google_fonts()
{
    wp_enqueue_style('custom-google-fonts', 'https://fonts.googleapis.com/css?family=Raleway:300,400,400i', false);
}

add_action('wp_enqueue_scripts', 'hs_wisu_custom_add_google_fonts');

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
if (!function_exists('hs_wisu_init_widget_area')) {
    function hs_wisu_init_widget_area()
    {
        register_sidebar(
            array(
                'name' => __('Before Content ', 'wisu'),
                'id' => 'before_content',
                'description' => __('Appears before the content.', 'wisu'),
                'before_widget' => '<section id="%1$s" class="widget %2$s">',
                'after_widget' => '</section>',
                'before_title' => '<h2 class="widget-title"><span>',
                'after_title' => '</span></h2>',
            )
        );

        register_sidebar(
            array(
                'name' => __('Right Sidebar', 'wisu'),
                'id' => 'right_sidebar',
                'description' => __('Right Sidebar', 'wisu'),
                'before_widget' => '<section id="%1$s" class="widget %2$s">',
                'after_widget' => '</section>',
                'before_title' => '<h2 class="widget-title"><span>',
                'after_title' => '</span></h2>',
            )
        );

        register_sidebar(
            array(
                'name' => __('Left Sidebar', 'wisu'),
                'id' => 'left_sidebar',
                'description' => __('Left Sidebar', 'wisu'),
                'before_widget' => '<section id="%1$s" class="widget %2$s">',
                'after_widget' => '</section>',
                'before_title' => '<h2 class="widget-title"><span>',
                'after_title' => '</span></h2>',
            )
        );

        register_sidebar(
            array(
                'name' => __('Before Footer', 'wisu'),
                'id' => 'before_footer',
                'description' => __('Appears after the content.', 'wisu'),
                'before_widget' => '<section id="%1$s" class="widget %2$s">',
                'after_widget' => '</section>',
                'before_title' => '<h2 class="widget-title"><span>',
                'after_title' => '</span></h2>',
            )
        );

        register_sidebar(
            array(
                'name' => __('Footer 1', 'wisu'),
                'id' => 'footer1',
                'description' => __('Footer 1', 'wisu'),
                'before_widget' => '<section id="%1$s" class="widget %2$s">',
                'after_widget' => '</section>',
                'before_title' => '<h2 class="widget-title"><span>',
                'after_title' => '</span></h2>',
            )
        );

        register_sidebar(
            array(
                'name' => __('Footer 2', 'wisu'),
                'id' => 'footer2',
                'description' => __('Footer 2', 'wisu'),
                'before_widget' => '<section id="%1$s" class="widget %2$s">',
                'after_widget' => '</section>',
                'before_title' => '<h2 class="widget-title"><span>',
                'after_title' => '</span></h2>',
            )
        );

        register_sidebar(
            array(
                'name' => __('Footer 3', 'wisu'),
                'id' => 'footer3',
                'description' => __('Footer 3', 'wisu'),
                'before_widget' => '<section id="%1$s" class="widget %2$s">',
                'after_widget' => '</section>',
                'before_title' => '<h2 class="widget-title"><span>',
                'after_title' => '</span></h2>',
            )
        );

        register_sidebar(
            array(
                'name' => __('Footer 4', 'wisu'),
                'id' => 'footer4',
                'description' => __('Footer 4', 'wisu'),
                'before_widget' => '<section id="%1$s" class="widget %2$s">',
                'after_widget' => '</section>',
                'before_title' => '<h2 class="widget-title"><span>',
                'after_title' => '</span></h2>',
            )
        );

        register_sidebar(
            array(
                'name' => __('CopyRight', 'wisu'),
                'id' => 'copyright',
                'description' => __('Copy Right', 'wisu'),
                'before_widget' => '<section id="%1$s" class="widget %2$s">',
                'after_widget' => '</section>',
                'before_title' => '<h2 class="widget-title"><span>',
                'after_title' => '</span></h2>',
            )
        );
    }

    add_action('widgets_init', 'hs_wisu_init_widget_area');
}

require_once "widgets/init.php";

if (!function_exists('hs_wisu_excerpt_more')) :
    /**
     * Remove ... From Excerpt
     *
     * @since 1.0.0
     */
    function hs_wisu_excerpt_more($more)
    {
        if (!is_admin()) {
            return '';
        }
    }
endif;
add_filter('excerpt_more', 'hs_wisu_excerpt_more');

if (!function_exists('hs_wisu_alter_excerpt')) :
    /**
     * Filter to change excerpt length size
     *
     * @since 1.0.0
     */
    function hs_wisu_alter_excerpt($length)
    {
        if (is_admin()) {
            return $length;
        }
        return 25;
    }
endif;
add_filter('excerpt_length', 'hs_wisu_alter_excerpt');

/*
 * Custom Comment Form
 */
function hs_wisu_custom_comment_list($comment, $args, $depth)
{ ?>
    <div <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
        <div id="div-comment-<?php comment_ID(); ?>" class="comment-body">
            <header>
                <?php
                if (0 != $args['avatar_size']):
                    $avatar = get_avatar($comment, $args['avatar_size']);
                    if ($avatar) {
                        ?>
                        <div class="comment-author-avatar">
                            <?php echo get_avatar($comment, $args['avatar_size']); ?>
                        </div>
                    <?php }
                endif; ?>
                <div class="comment-metadata">
                    <div class="comment-author-name">
                        <?php echo wp_kses(get_comment_author_link(),array('a' => array('href' => array()))); ?>
                    </div>
                    <a href="<?php echo esc_url(get_comment_link($comment->comment_ID)); ?>">
                        <time datetime="<?php comment_time('c'); ?>">
                            <?php echo esc_html(get_comment_date()); ?>
                        </time>
                    </a>
                    <?php edit_comment_link(esc_html__('(Edit)', 'wisu'), '<span class="edit-link">', '</span>'); ?>
                </div>
            </header>
            <div class="comment-content">
                <?php comment_text(); ?>
            </div>
            <div class="reply">
                <?php comment_reply_link(array_merge($args, array('add_below' => 'div-comment', 'class' => 'btn', 'depth' => $depth, 'max_depth' => $args['max_depth']))); ?>
            </div>
            <footer class="comment-meta">

                <?php if ('0' == $comment->comment_approved) : ?>
                    <p class="comment-awaiting-moderation"><?php esc_html_e('Your comment is awaiting moderation.', 'wisu'); ?></p>
                <?php endif; ?>
            </footer>
        </div>
    </div>
    <?php
}

add_filter('comment_reply_link', 'hs_wisu_replace_reply_link_class');
function hs_wisu_replace_reply_link_class($class)
{
    $class = str_replace("class='comment-reply-link", "class='btn", $class);
    return $class;
}

if (!function_exists('hs_wisu_move_comment_field_to_bottom')) {
    function hs_wisu_move_comment_field_to_bottom($fields)
    {
        $comment_field = $fields['comment'];
        unset($fields['comment']);
        $fields['comment'] = $comment_field;
        return $fields;
    }

    add_filter('comment_form_fields', 'hs_wisu_move_comment_field_to_bottom');
}

remove_action('set_comment_cookies', 'wp_set_comment_cookies');

add_action('hs_wisu_related_posts', 'wisu_related_posts_by_category', 10, 3);
function hs_wisu_related_posts_by_category($post_id, $related_count, $args = array())
{

    $terms = get_the_terms($post_id, 'category');

    if (empty($terms)) $terms = array();

    $term_list = wp_list_pluck($terms, 'slug');

    $related_args = array(
        'post_type' => 'post',
        'posts_per_page' => $related_count,
        'post_status' => 'publish',
        'post__not_in' => array($post_id),
        'orderby' => 'rand',
        'tax_query' => array(
            array(
                'taxonomy' => 'category',
                'field' => 'slug',
                'terms' => $term_list
            )
        )
    );

    $the_query = new WP_Query($related_args);
    global $cl_from_element;
    $cl_from_element['is_related'] = true;
    // Display posts
    if ($the_query->have_posts()) :

        ?>
        <?php $counter = 1;
        while ($the_query->have_posts() && $counter < 4) :
            $the_query->the_post();
            if (has_post_thumbnail()):?>
                <div class="related-post">
                    <div class="related-post-thumbnail">
                        <a href="<?php echo esc_url(get_permalink()); ?>"
                           style="background-image: url(<?php echo esc_url(get_the_post_thumbnail_url()); ?>)"></a>
                    </div>

                    <?php the_title(sprintf('<h2 class="related-post-title"><a href="%s" rel="bookmark">', esc_url(get_permalink())), '</a></h2>'); ?>
                </div>
                <?php
            endif;
            $counter++;
        endwhile;
        ?>

    <?php endif;

    wp_reset_query();
    $cl_from_element['is_related'] = false;
}

if (!function_exists('hs_wisu_tag_cloud_widget')) :
    /**
     * Function to modify tag clouds font size
     *
     * @param none
     * @return array $args
     *
     * @since 1.0.0
     *
     */
    function hs_wisu_tag_cloud_widget($args)
    {
        $args['largest'] = 12; //largest tag
        $args['smallest'] = 12; //smallest tag
        $args['unit'] = 'px'; //tag font unit
        return $args;
    }

    add_filter('widget_tag_cloud_args', 'hs_wisu_tag_cloud_widget');
endif;

if (!function_exists('hs_wisu_customizer_register')) {
    function hs_wisu_customizer_register($wp_customize)
    {
        $wp_customize->add_setting(
            'wisu_theme_color',
            array('default' => '#f47742', 'sanitize_callback' => 'sanitize_hex_color')
        );

        $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'wisu_theme_color', array(
            'label' => __('Theme Color', 'wisu'),
            'section' => 'colors',
            'settings' => 'wisu_theme_color',
        )));
    }

    add_action('customize_register', 'hs_wisu_customizer_register');
}

if (!function_exists('hs_wisu_customizer_css')) {
    function hs_wisu_customizer_css()
    {
        ?>
        <style type="text/css">
            :root {
                --theme-color: <?php echo esc_attr(get_theme_mod('wisu_theme_color','#f47742')); ?>;
            }

            .site-header .wisu-header,
            .site-header .wisu-header a{
                color: #<?php echo esc_attr(header_textcolor()); ?>;
            }
        </style>
        <?php
    }

    add_action('wp_head', 'hs_wisu_customizer_css');
}

/*Remove extra attributes from link and script tag*/
add_action('wp_loaded', 'hs_wisu_output_buffer_start');
function hs_wisu_output_buffer_start()
{
    ob_start("hs_wisu_output_callback");
}

function hs_wisu_output_callback($buffer)
{
    return preg_replace("%[ ]type=[\'\"]text\/(javascript|css)[\'\"]%", '', $buffer);
}