<?php
/**
 * The header.
 *
 * This is the template that displays all of the <head> section and everything up until main.
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package WordPress
 * @subpackage WiSu
 * @since WiSu 1.0
 */
?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
    <meta charset="<?php bloginfo('charset'); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<?php wp_body_open(); ?>
<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e('Skip to content', 'wisu'); ?></a>
<button class="to-top" onclick='window.scrollTo({top: 0, behavior: "smooth"});'>
    <i class="fa fa-arrow-up" aria-hidden="true"></i>
</button>
<header class="site-header">
    <div class="wisu-header">
        <div class="logo">
            <?php /*display website logo*/ ?>
            <?php if (has_custom_logo()) : ?>
                <div class="site-logo">
                    <?php echo wp_kses(get_custom_logo(), array('a' => array('href' => array()), 'img' => array('width' => array(), 'height' => array(), 'src' => array(), 'alt' => array(), 'title' => array()))); ?>
                </div>
            <?php else:
                if (display_header_text() == true):?>
                    <div class="site-title">
                        <h1>
                            <a href="<?php echo esc_url(home_url()); ?>">
                                <?php bloginfo('name'); /*display website name*/ ?>
                            </a>
                        </h1>
                        <span><?php bloginfo('description'); /*display website description*/ ?></span>
                    </div>
                <?php
                endif;
            endif; ?>
        </div>
        <div class="header-menu">
            <a class="mobile-btn" tabindex="0">
                <i class="fa fa-bars"></i>
            </a>
            <?php
            if (has_nav_menu('main-menu')) {
                wp_nav_menu(array(
                    'menu' => 'main-menu',
                    'theme_location' => 'main-menu',
                    'menu_class' => 'menu',
                    'container' => 'ul'));
            } ?>
        </div>
        <div class="social-media">
            <?php
            if (has_nav_menu('social-menu')) {
                wp_nav_menu(array(
                    'menu' => 'social-menu',
                    'theme_location' => 'social-menu',
                    'container' => 'ul'));
            } ?>
        </div>
    </div>
</header>
