<?php
/**
 * WiSu single post template
 *
 * @package wisu
 */

if (!defined('ABSPATH')) {
    exit;
}
?>
<div class="wisu-wrap single page" id="content">
    <?php if (have_posts()) : ?>
        <?php while (have_posts()):/* loop start*/
            the_post(); ?>
            <article id="post-<?php the_ID(); ?>" <?php post_class('post'); ?>>
                <div class="entry-categories">
                    <?php
                    $categories_list = get_the_category_list(_x(', ', 'Used between list items, there is a space after the comma.', 'wisu'));
                    if ($categories_list) {
                        printf('<span class="screen-reader-text">%1$s </span>%2$s', esc_html__('Used before category names.', 'wisu'), wp_kses($categories_list, array('a' => array('href' => array(), 'rel' => array()))));
                    } ?>
                </div>
                <div class="entry-header">
                    <?php if (is_sticky()): ?>
                        <h1 class="entry-title"><i class="fa fa-thumb-tack" aria-hidden="true"></i><?php the_title(); ?>
                        </h1>
                    <?php else: ?>
                        <h2 class="entry-title"><?php the_title(); ?></h2>
                    <?php endif; ?>
                </div>
                <div class="line"></div>
                <?php if (has_post_thumbnail()): ?>
                    <div class="post-thumbnail">
                        <?php
                        /*display post thumbnail*/
                        the_post_thumbnail('post-thumbnail', array('alt' => the_title_attribute('echo=0'), 'class' => '')); ?>
                    </div>
                <?php endif; ?>
                <div class="wisu-content">
                    <?php if (is_active_sidebar('left_sidebar')) : ?>
                        <div class="sidebar-left sidebar">
                            <?php dynamic_sidebar('left_sidebar'); ?>
                        </div>
                    <?php endif; ?>
                    <div class="entry-content">
                        <?php the_content(); ?>
                        <?php
                        wp_link_pages(
                            array(
                                'before' => '<div class="page-links"><span class="page-links-title">' . __('Pages:', 'wisu') . '</span>',
                                'after' => '</div>',
                                'link_before' => '<span>',
                                'link_after' => '</span>',
                                'pagelink' => '<span class="screen-reader-text">' . __('Page', 'wisu') . ' </span>%',
                                'separator' => '<span class="screen-reader-text">, </span>',
                            )
                        );
                        ?>
                        <?php if (is_single()): ?>
                            <div class="entry-tags">
                                <?php
                                /* display post tags*/
                                $tags_list = get_the_tag_list('', _x(', ', 'Used between list items, there is a space after the comma.', 'wisu'));
                                if ($tags_list && !is_wp_error($tags_list)) {
                                    printf(
                                        '%1$s %2$s',
                                        wp_kses(__('<i class="fa fa-tags"></i>', 'wisu'),array('a' => array('class' => array()))),
                                        wp_kses($tags_list, array('a' => array('href' => array(), 'rel' => array())))

                                    );
                                }
                                ?>
                            </div>
                        <?php endif; ?>
                        <?php if (is_single()): ?>
                            <div class="entry-avatar">
                                <?php
                                /* display post authors name and image*/
                                if ('post' === get_post_type()) {
                                    /*Display writer avatar and name in single post*/
                                    $author_avatar_size = apply_filters('wisu_author_avatar_size', 150); ?>
                                    <div class="author">
                                        <span class="screen-reader-text"><?php esc_html_e('Used before post author name.', 'wisu'); ?></span>
                                        <div class="author-avatar"><?php echo get_avatar(get_the_author_meta('user_email'), $author_avatar_size); ?></div>
                                        <div class="author-name"><a
                                                    href="<?php echo esc_url(get_author_posts_url(get_the_author_meta('ID'))); ?>"><?php echo get_the_author(); ?></a>
                                        </div>
                                        <div class="author-description"><?php echo esc_html(get_the_author_meta('description')); ?></div>
                                    </div>
                                    <?php
                                }
                                ?>
                            </div>
                        <?php endif; ?>

                        <?php
                        $prev_post = get_adjacent_post(false, '', true);
                        $next_post = get_adjacent_post(false, '', false);
                        if (!empty($prev_post) || !empty($next_post)):
                            ?>
                            <div class="post-navigation">
                                <div class="pre-post">
                                    <?php
                                    if (!empty($prev_post)) {
                                        echo '<a href="' . esc_url(get_permalink($prev_post->ID)) . '" title="' . esc_html($prev_post->post_title) . '"><i class="fa fa-angle-left"></i>' . esc_html($prev_post->post_title) . '</a>';
                                    }
                                    ?>
                                </div>
                                <div class="next-post">
                                    <?php

                                    if (!empty($next_post)) {
                                        echo '<a href="' . esc_url(get_permalink($next_post->ID)) . '" title="' . esc_html($next_post->post_title) . '">' . esc_html($next_post->post_title) . '<i class="fa fa-angle-right"></i></a>';
                                    }
                                    ?>
                                </div>
                            </div>
                        <?php endif; ?>

                        <?php if (is_single()): ?>
                            <?php
                            $categories = get_the_category();
                            if (count($categories) > 0):
                                ?>
                                <div class="related-posts">
                                    <?php
                                    //                                    $cat_id = $categories[0]->ID;
                                    do_action('wisu_related_posts', get_the_ID(), $categories[0]->ID);
                                    ?>
                                </div>
                            <?php endif;
                        endif; ?>

                        <div class="entry-comment">
                            <?php
                            /* display comments and comment form*/
                            if (comments_open() || get_comments_number()) {
                                comments_template();
                            } elseif (!comments_open()) {
                                esc_html_e('Comments are closed for this post.', 'wisu');
                            }
                            ?>
                        </div>
                    </div>
                    <?php if (is_active_sidebar('right_sidebar')) : ?>
                        <div class="sidebar-right sidebar">
                            <?php dynamic_sidebar('right_sidebar'); ?>
                        </div>
                    <?php endif; ?>
                </div>
            </article>
        <?php endwhile; ?>
    <?php endif; ?>
</div>