<?php
/**
 * WiSu blog list
 *
 * @package wisu
 */
?>
<div id="content">
<?php
if (get_header_image() && is_front_page()) :
    /**
     * Filter the default wisu custom header sizes attribute.
     */
    $custom_header_sizes = apply_filters('wisu_custom_header_sizes', '(max-width: 709px) 85vw, (max-width: 909px) 81vw, (max-width: 1362px) 88vw, 1200px');
    ?>
    <div class="wisu-header-image">
        <img src="<?php esc_url(header_image()); ?>"
             srcset="<?php echo esc_attr(wp_get_attachment_image_srcset(get_custom_header()->attachment_id)); ?>"
             sizes="<?php echo esc_attr($custom_header_sizes); ?>"
             width="<?php echo esc_attr(get_custom_header()->width); ?>"
             height="<?php echo esc_attr(get_custom_header()->height); ?>"
             alt="<?php echo esc_attr(get_bloginfo('name', 'display')); ?>">
    </div>
<?php endif; ?>
<?php if (is_active_sidebar('before_content') && is_front_page()) : ?>
    <div class="before-content">
        <?php dynamic_sidebar('before_content'); ?>
    </div>
<?php endif; ?>

<?php if (is_search()) { ?>
    <h1 class="page-title"><?php echo esc_html('Search Results for: ', 'wisu') . esc_html(get_search_query()); ?></h1>
    <div class="line"></div>
<?php } elseif(is_archive()) {
    the_archive_title('<h1 class="page-title">', '</h1>');
    the_archive_description('<div class="archive-description">', '</div>');
    ?>
    <div class="line"></div>
<?php } ?>

<div class="wisu-content">
    <?php if (is_active_sidebar('left_sidebar')) : ?>
        <div class="sidebar-left sidebar">
            <?php dynamic_sidebar('left_sidebar'); ?>
        </div>
    <?php endif; ?>
    <div class="posts-list">
        <div class="posts">
            <?php if (have_posts()) : ?>
                <?php while (have_posts()):/* loop start*/
                    the_post(); ?>
                    <article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
                        <?php if (has_post_thumbnail()):
                            /*check there is post thumbnail
                            */ ?>
                            <div class="post-thumbnail">
                                <a href="<?php echo esc_url(get_permalink()); ?>"
                                   style="background-image: url(<?php echo esc_url(get_the_post_thumbnail_url()); ?>)"></a>
                            </div>
                        <?php endif; ?>
                        <?php
                        $categories = get_the_category();
                        if ($categories):
                            ?>
                            <div class="entry-category">
                                <?php
                                $cat_name = $categories[0]->cat_name;
                                ?>
                                <a href="<?php echo esc_url(get_category_link($categories[0]->cat_ID)); ?>"><?php echo esc_html($cat_name); ?></a>
                            </div>
                        <?php endif; ?>
                        <?php
                        if(is_sticky()){
                            the_title(sprintf('<h2 class="entry-title"><i class="fa fa-thumb-tack" aria-hidden="true"></i><a href="%s" rel="bookmark">', esc_url(get_permalink())), '</a></h2>');
                        }
                        else{
                            the_title(sprintf('<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url(get_permalink())), '</a></h2>');
                        }
                        ?>
                        <div class="line"></div>
                        <div class="entry-meta">
                                        <span><?php the_author(); ?>
                                            &#8212; <?php echo esc_html(get_the_date()); ?></span>
                        </div>
                        <div class="entry-content">
                            <?php the_excerpt(); ?>
                        </div>
                        <div class="entry-footer">
                            <div class="comment">
                                <?php if (comments_open()):
                                    /*display comments count*/
                                    $comments_number = get_comments_number(); ?>
                                    <?php if ('0' === $comments_number): ?>
                                    0 <i class="fa fa-comments"></i>
                                <?php elseif ('1' === $comments_number): ?>
                                    1 <i class="fa fa-comments"></i>
                                <?php else: ?>
                                    <?php echo esc_html($comments_number); ?> <i class="fa fa-comments"></i>
                                <?php endif; ?>
                                <?php endif; ?>
                            </div>
                            <div class="read-more">
                                <a href="<?php echo esc_url(get_permalink()) ?>"
                                   rel="bookmark" class="btn"><?php esc_html_e('Read more', 'wisu'); ?></a>
                            </div>
                        </div>
                    </article>
                <?php endwhile; ?>
            <?php endif; ?>
        </div>
        <?php
        $is_paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
        $the_query = new WP_Query('paged=' . $is_paged);
        if ($the_query->have_posts()) :?>
            <div class="load-more">
                <div class="old-posts">
                    <?php next_posts_link(__('<i class="fa fa-angle-left"></i> Older Posts', 'wisu'), $the_query->max_num_pages); ?>
                </div>
                <div class="new-posts">
                    <?php previous_posts_link(__('Newer Posts <i class="fa fa-angle-right"></i>', 'wisu'));
                    // clean up after our query
                    wp_reset_postdata(); ?>
                </div>
            </div>
        <?php endif; ?>

    </div>
    <?php if (is_active_sidebar('right_sidebar')) : ?>
        <div class="sidebar-right sidebar">
            <?php dynamic_sidebar('right_sidebar'); ?>
        </div>
    <?php endif; ?>
</div>
<?php if (is_active_sidebar('before_footer')) : ?>
    <div class="before-footer">
        <?php dynamic_sidebar('before_footer'); ?>
    </div>
<?php endif; ?>
</div>
