<?php
/*
 * WiSu About Me Widget
 *
 * @since 1.0
 */
if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('WiSu_About_Author')) {
    class WiSu_About_Author extends WP_Widget
    {
        private $prefix = 'hs_wisu_about_author_';
        private $allowed_html = array('a' => array('href' => array(), 'title' => array()), 'br' => array(), 'em' => array(), 'strong' => array(), 'span' => array(), 'h2' => array('class' => array()), 'section' => array('class' => array(), 'id' => array()),);

        function __construct()
        {
            parent::__construct(
                $this->prefix . 'widget',
                esc_html__('WiSu: About Author', 'wisu'),
                array('description' => esc_html__('About Author Widget', 'wisu'),)
            );
        }

        public function widget($args, $instance)
        {
            extract($args, EXTR_SKIP);
            $title = apply_filters('widget_title', empty($instance['title']) ? '' : $instance['title'], $instance, $this->id_base);
            $description = !empty($instance[$this->prefix . 'description']) ? trim($instance[$this->prefix . 'description']) : '';
            $image = !empty($instance[$this->prefix . 'image']) ? $instance[$this->prefix . 'image'] : '';
            $author_facebook = !empty($instance[$this->prefix . 'facebook']) ? $instance[$this->prefix . 'facebook'] : '';
            $author_twitter = !empty($instance[$this->prefix . 'twitter']) ? $instance[$this->prefix . 'twitter'] : '';
            $author_linkedin = !empty($instance[$this->prefix . 'linkedin']) ? $instance[$this->prefix . 'linkedin'] : '';
            $author_instagram = !empty($instance[$this->prefix . 'instagram']) ? $instance[$this->prefix . 'instagram'] : '';
            $author_pinterest = !empty($instance[$this->prefix . 'pinterest']) ? $instance[$this->prefix . 'pinterest'] : '';
            $author_youtube = !empty($instance[$this->prefix . 'youtube']) ? $instance[$this->prefix . 'youtube'] : '';
            $author_vk = !empty($instance[$this->prefix . 'vk']) ? $instance[$this->prefix . 'vk'] : '';
            $author_sign = !empty($instance[$this->prefix . 'sign']) ? $instance[$this->prefix . 'sign'] : '';
            ob_start();
            echo wp_kses($args['before_widget'], $this->allowed_html);
            if ($title) {
                echo wp_kses($args['before_title'], $this->allowed_html) . esc_html($title) . wp_kses($args['after_title'], $this->allowed_html);
            }
            ?>
            <div class="widget-content">
                <?php if ($image): ?>
                    <div class="avatar">
                        <img src="<?php echo esc_url($image); ?>">
                    </div>
                <?php endif; ?>
                <div class="description">
                    <?php echo wp_kses($description, $this->allowed_html); ?>
                </div>
                <?php
                if (isset($author_sign) && !empty($author_sign)) {
                    ?>
                    <figure class="wisu-author-sign">
                        <img src="<?php echo esc_url($instance[$this->prefix . 'sign']); ?>">
                    </figure>
                    <?php
                }
                ?>
                <?php if ($author_facebook || $author_twitter || $author_linkedin || $author_instagram || $author_pinterest || $author_youtube || $author_vk) { ?>
                    <ul class="wisu-author-social">
                        <?php if ($author_facebook) { ?>
                            <li>
                                <a href="<?php echo esc_url($author_facebook); ?>" target="_blank"><span
                                            class="screen-reader-text"><?php esc_html_e('facebook', 'wisu'); ?></span><i
                                            class="fa fa-facebook"></i></a>
                            </li>
                        <?php } ?>

                        <?php if ($author_twitter) { ?>
                            <li>
                                <a href="<?php echo esc_url($author_twitter); ?>" target="_blank"><span
                                            class="screen-reader-text"><?php esc_html_e('twitter', 'wisu'); ?></span><i
                                            class="fa fa-twitter"></i></a>
                            </li>
                        <?php } ?>

                        <?php if ($author_linkedin) { ?>
                            <li>
                                <a href="<?php echo esc_url($author_linkedin); ?>" target="_blank"><span
                                            class="screen-reader-text"><?php esc_html_e('linkedin', 'wisu'); ?></span><i
                                            class="fa fa-linkedin"></i></a>
                            </li>
                        <?php } ?>

                        <?php if ($author_instagram) { ?>
                            <li>
                                <a href="<?php echo esc_url($author_instagram); ?>" target="_blank"><span
                                            class="screen-reader-text"><?php esc_html_e('instagram', 'wisu'); ?></span><i
                                            class="fa fa-instagram"></i></a>
                            </li>
                        <?php } ?>

                        <?php if ($author_pinterest) { ?>
                            <li>
                                <a href="<?php echo esc_url($author_pinterest); ?>" target="_blank"><span
                                            class="screen-reader-text"><?php esc_html_e('pinterest', 'wisu'); ?></span><i
                                            class="fa fa-pinterest"></i></a>
                            </li>
                        <?php } ?>

                        <?php if ($author_youtube) { ?>
                            <li>
                                <a href="<?php echo esc_url($author_youtube); ?>" target="_blank"><span
                                            class="screen-reader-text"><?php esc_html_e('youtube', 'wisu'); ?></span><i
                                            class="fa fa-youtube"></i></a>
                            </li>
                        <?php } ?>

                        <?php if ($author_vk) { ?>
                            <li>
                                <a href="<?php echo esc_url($author_vk); ?>" target="_blank"><span
                                            class="screen-reader-text"><?php esc_html_e('vk', 'wisu'); ?></span><i
                                            class="fa fa-vk"></i></a>
                            </li>
                        <?php } ?>

                    </ul>

                <?php } ?>
            </div>
            <?php
            echo wp_kses($args['after_widget'], $this->allowed_html);
            ob_end_flush();
        }

        public function form($instance)
        {
            $defaults = array(
                'title' => '',
                $this->prefix . 'image' => '',
                $this->prefix . 'description' => '',
                $this->prefix . 'facebook' => '',
                $this->prefix . 'twitter' => '',
                $this->prefix . 'linkedin' => '',
                $this->prefix . 'instagram' => '',
                $this->prefix . 'pinterest' => '',
                $this->prefix . 'youtube' => '',
                $this->prefix . 'vk' => '',
            );
            extract(wp_parse_args(( array )$instance, $defaults));
            $title = !empty($instance['title']) ? $instance['title'] : '';
            $description = !empty($instance[$this->prefix . 'description']) ? trim($instance[$this->prefix . 'description']) : '';
            $image = !empty($instance[$this->prefix . 'image']) ? $instance[$this->prefix . 'image'] : '';
            $author_facebook = !empty($instance[$this->prefix . 'facebook']) ? $instance[$this->prefix . 'facebook'] : '';
            $author_twitter = !empty($instance[$this->prefix . 'twitter']) ? $instance[$this->prefix . 'twitter'] : '';
            $author_linkedin = !empty($instance[$this->prefix . 'linkedin']) ? $instance[$this->prefix . 'linkedin'] : '';
            $author_instagram = !empty($instance[$this->prefix . 'instagram']) ? $instance[$this->prefix . 'instagram'] : '';
            $author_pinterest = !empty($instance[$this->prefix . 'pinterest']) ? $instance[$this->prefix . 'pinterest'] : '';
            $author_youtube = !empty($instance[$this->prefix . 'youtube']) ? $instance[$this->prefix . 'youtube'] : '';
            $author_vk = !empty($instance[$this->prefix . 'vk']) ? $instance[$this->prefix . 'vk'] : '';
            $author_sign = !empty($instance[$this->prefix . 'sign']) ? $instance[$this->prefix . 'sign'] : '';

            ?>
            <div class="wisu-about">
                <h3>Title</h3>
                <p>
                    <label
                            for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title:', 'wisu'); ?></label>
                    <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>"
                           name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text"
                           value="<?php echo esc_attr($title); ?>"
                           placeholder="Title">
                </p>

                <p>
                    <label for="<?php echo esc_attr($this->get_field_id($this->prefix . 'image')); ?>"><?php esc_html_e('Image:', 'wisu'); ?></label>
                    <img class="widefat" src="<?php echo esc_url($image); ?>"/>
                    <input class="widefat" id="<?php echo esc_attr($this->get_field_id($this->prefix . 'image')); ?>"
                           name="<?php echo esc_attr($this->get_field_name($this->prefix . 'image')); ?>" type="hidden"
                           value="<?php echo esc_url($image); ?>"/>
                    <button class="upload_image_button button button-primary"><?php esc_html_e('Upload Image', 'wisu') ?></button>
                </p>

                <p>
                    <label for="<?php echo esc_attr($this->get_field_id($this->prefix . 'description')); ?>"><?php esc_html_e('Description:', 'wisu'); ?></label>
                    <textarea class="widefat"
                              id="<?php echo esc_attr($this->get_field_id($this->prefix . 'description')); ?>"
                              name="<?php echo esc_attr($this->get_field_name($this->prefix . 'description')); ?>"><?php echo wp_kses($description, $this->allowed_html); ?>
                    </textarea>
                </p>

                <p>
                    <label for="<?php echo esc_attr($this->get_field_id($this->prefix . 'sign')); ?>">
                        <?php esc_html_e('Upload Author Signature Image', 'wisu'); ?>
                    </label>
                    <br/>
                    <?php
                    if (!empty($author_sign)) :
                        echo '<img class="widefat custom_media_image" src="' . esc_url($author_sign) . '" />';
                    endif;
                    ?>

                    <input type="text" class="widefat custom_media_url"
                           name="<?php echo esc_attr($this->get_field_name($this->prefix . 'sign')); ?>"
                           id="<?php echo esc_attr($this->get_field_id($this->prefix . 'sign')); ?>" value="<?php
                    if (!empty($author_sign)) :
                        echo esc_url($author_sign);
                    endif;
                    ?>">
                    <input type="button" class="button button-primary upload_image_button" id="custom_media_button"
                           name="<?php echo esc_attr($this->get_field_name($this->prefix . 'sign')); ?>"
                           value="<?php esc_attr_e('Upload Sign', 'wisu') ?>"/>
                </p>

                <p>
                    <label for="<?php echo esc_attr($this->get_field_name($this->prefix . 'facebook')); ?>">
                        <?php esc_html_e('Facebook:', 'wisu'); ?>
                    </label>
                    <input class="widefat" id="<?php echo esc_attr($this->get_field_id($this->prefix . 'facebook')); ?>"
                           name="<?php echo esc_attr($this->get_field_name($this->prefix . 'facebook')); ?>" type="text"
                           value="<?php echo esc_url($author_facebook); ?>"/>
                </p>

                <p>
                    <label for="<?php echo esc_attr($this->get_field_name($this->prefix . 'twitter')); ?>">
                        <?php esc_html_e('Twitter:', 'wisu'); ?>
                    </label>
                    <input class="widefat" id="<?php echo esc_attr($this->get_field_id($this->prefix . 'twitter')); ?>"
                           name="<?php echo esc_attr($this->get_field_name($this->prefix . 'twitter')); ?>" type="text"
                           value="<?php echo esc_url($author_twitter); ?>"/>
                </p>

                <p>
                    <label for="<?php echo esc_attr($this->get_field_name($this->prefix . 'linkedin')); ?>">
                        <?php esc_html_e('LinkedIn:', 'wisu'); ?>
                    </label>
                    <input class="widefat" id="<?php echo esc_attr($this->get_field_id($this->prefix . 'linkedin')); ?>"
                           name="<?php echo esc_attr($this->get_field_name($this->prefix . 'linkedin')); ?>" type="text"
                           value="<?php echo esc_url($author_linkedin); ?>"/>
                </p>

                <p>
                    <label for="<?php echo esc_attr($this->get_field_name($this->prefix . 'instagram')); ?>">
                        <?php esc_html_e('Instagram:', 'wisu'); ?>
                    </label>
                    <input class="widefat"
                           id="<?php echo esc_attr($this->get_field_id($this->prefix . 'instagram')); ?>"
                           name="<?php echo esc_attr($this->get_field_name($this->prefix . 'instagram')); ?>"
                           type="text"
                           value="<?php echo esc_url($author_instagram); ?>"/>
                </p>

                <p>
                    <label for="<?php echo esc_attr($this->get_field_name($this->prefix . 'pinterest')); ?>">
                        <?php esc_html_e('Pinterest:', 'wisu'); ?>
                    </label>
                    <input class="widefat"
                           id="<?php echo esc_attr($this->get_field_id($this->prefix . 'pinterest')); ?>"
                           name="<?php echo esc_attr($this->get_field_name($this->prefix . 'pinterest')); ?>"
                           type="text"
                           value="<?php echo esc_url($author_pinterest); ?>"/>
                </p>

                <p>
                    <label for="<?php echo esc_attr($this->get_field_name($this->prefix . 'youtube')); ?>">
                        <?php esc_html_e('Youtube:', 'wisu'); ?>
                    </label>
                    <input class="widefat" id="<?php echo esc_attr($this->get_field_id($this->prefix . 'youtube')); ?>"
                           name="<?php echo esc_attr($this->get_field_name($this->prefix . 'youtube')); ?>" type="text"
                           value="<?php echo esc_url($author_youtube); ?>"/>
                </p>

                <p>
                    <label for="<?php echo esc_attr($this->get_field_name($this->prefix . 'vk')); ?>">
                        <?php esc_html_e('VK:', 'wisu'); ?>
                    </label>
                    <input class="widefat" id="<?php echo esc_attr($this->get_field_id($this->prefix . 'vk')); ?>"
                           name="<?php echo esc_attr($this->get_field_name($this->prefix . 'vk')); ?>" type="text"
                           value="<?php echo esc_url($author_vk); ?>"/>
                </p>
            </div>
            <?php
        }

        public function update($new_instance, $old_instance)
        {
            $instance = $old_instance;
            $instance['title'] = (!empty($new_instance['title'])) ? sanitize_text_field($new_instance['title']) : '';
            $instance[$this->prefix . 'description'] = (!empty($new_instance[$this->prefix . 'description'])) ? wp_kses($new_instance[$this->prefix . 'description'], $this->allowed_html) : '';
            $instance[$this->prefix . 'image'] = (!empty($new_instance[$this->prefix . 'image'])) ? sanitize_text_field($new_instance[$this->prefix . 'image']) : '';
            $instance[$this->prefix . 'facebook'] = esc_url_raw($new_instance[$this->prefix . 'facebook']);

            $instance[$this->prefix . 'twitter'] = esc_url_raw($new_instance[$this->prefix . 'twitter']);

            $instance[$this->prefix . 'linkedin'] = esc_url_raw($new_instance[$this->prefix . 'linkedin']);

            $instance[$this->prefix . 'instagram'] = esc_url_raw($new_instance[$this->prefix . 'instagram']);

            $instance[$this->prefix . 'pinterest'] = esc_url_raw($new_instance[$this->prefix . 'pinterest']);

            $instance[$this->prefix . 'youtube'] = esc_url_raw($new_instance[$this->prefix . 'youtube']);

            $instance[$this->prefix . 'vk'] = esc_url_raw($new_instance[$this->prefix . 'vk']);

            $instance[$this->prefix . 'sign'] = esc_url_raw($new_instance[$this->prefix . 'sign']);
            return $instance;
        }
    }
}

add_action('wp_enqueue_scripts', 'enqueue_WiSu_About_Author_script');
function enqueue_WiSu_About_Author_script()
{
    wp_enqueue_style('wisu_about_author_style', get_template_directory_uri() . '/widgets/about-author/about-author.css', array('wisu-style'), null);
}

add_action('admin_enqueue_scripts', 'admin_enqueue_WiSu_About_Author_script');
function admin_enqueue_WiSu_About_Author_script()
{
    wp_enqueue_script('media-upload');
    wp_enqueue_media();
    wp_enqueue_script('wisu_about_author_admin', get_template_directory_uri() . '/widgets/about-author/admin.js', array('jquery'));
}