<?php
/*
 * WiSu About Widget
 *
 * @since 1.0
 */
if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('WiSu_About')) {
    class WiSu_About extends WP_Widget
    {
        private $prefix = 'hs_wisu_about_';
        private $allowed_html = array('a' => array('href' => array(), 'title' => array()), 'br' => array(), 'em' => array(), 'strong' => array(), 'span' => array(), 'h2' => array('class' => array()), 'section' => array('class' => array(), 'id' => array()),);

        function __construct()
        {
            parent::__construct(
                $this->prefix . 'widget',
                esc_html__('WiSu: About', 'wisu'),
                array('description' => esc_html__('Add about to your page.', 'wisu'),)
            );
        }

        public function widget($args, $instance)
        {
            extract($args, EXTR_SKIP);
            $title = apply_filters('widget_title', empty($instance['title']) ? '' : $instance['title'], $instance, $this->id_base);
            $description = !empty($instance[$this->prefix . 'description']) ? trim($instance[$this->prefix . 'description']) : '';
            $image = !empty($instance[$this->prefix . 'image']) ? $instance[$this->prefix . 'image'] : '';
            ob_start();
            echo wp_kses($args['before_widget'], $this->allowed_html);
            ?>
            <div class="wisu-about">
                <?php
                if ($title) {
                    echo wp_kses($args['before_title'], $this->allowed_html) . esc_html($title) . wp_kses($args['after_title'], $this->allowed_html);
                }
                ?>
                <div class="widget-content">
                    <p><?php echo wp_kses($description, $this->allowed_html); ?></p>
                    <?php if ($image): ?>
                        <img src="<?php echo esc_url($image); ?>">
                    <?php endif; ?>
                </div>
            </div>
            <?php
            echo wp_kses($args['after_widget'], $this->allowed_html);
            ob_end_flush();
        }

        public function form($instance)
        {
            $defaults = array(
                'title' => '',
                $this->prefix . 'image' => '',
            );
            extract(wp_parse_args(( array )$instance, $defaults));
            $title = !empty($instance['title']) ? $instance['title'] : '';
            $description = !empty($instance[$this->prefix . 'description']) ? trim($instance[$this->prefix . 'description']) : '';
            $image = !empty($instance[$this->prefix . 'image']) ? $instance[$this->prefix . 'image'] : '';
            ?>
            <div class="wisu-about">
                <h3>Title</h3>
                <p>
                    <label
                            for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title:', 'wisu'); ?></label>
                    <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>"
                           name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text"
                           value="<?php echo esc_attr($title); ?>"
                           placeholder="Title">
                </p>

                <p>
                    <label for="<?php echo esc_attr($this->get_field_id($this->prefix . 'description')); ?>"><?php esc_html_e('Description:', 'wisu'); ?></label>
                    <textarea class="widefat"
                              id="<?php echo esc_attr($this->get_field_id($this->prefix . 'description')); ?>"
                              name="<?php echo esc_attr($this->get_field_name($this->prefix . 'description')); ?>">
                        <?php echo wp_kses($description, $this->allowed_html); ?>
                    </textarea>
                </p>

                <p>
                    <label for="<?php echo esc_attr($this->get_field_id($this->prefix . 'image')); ?>"><?php esc_html_e('Image:', 'wisu'); ?></label>
                    <img class="widefat" src="<?php echo esc_url($image); ?>"/>
                    <input class="widefat" id="<?php echo esc_attr($this->get_field_id($this->prefix . 'image')); ?>"
                           name="<?php echo esc_attr($this->get_field_name($this->prefix . 'image')); ?>" type="hidden"
                           value="<?php echo esc_url($image); ?>"/>
                    <button class="upload_image_button button button-primary"><?php esc_html_e('Upload Image', 'wisu') ?></button>
                </p>
            </div>
            <?php
        }

        public function update($new_instance, $old_instance)
        {
            $instance = $old_instance;
            $instance['title'] = (!empty($new_instance['title'])) ? sanitize_text_field($new_instance['title']) : '';
            $instance[$this->prefix . 'description'] = (!empty($new_instance[$this->prefix . 'description'])) ? wp_kses(trim($new_instance[$this->prefix . 'description']), $this->allowed_html) : '';
            $instance[$this->prefix . 'image'] = (!empty($new_instance[$this->prefix . 'image'])) ? sanitize_text_field($new_instance[$this->prefix . 'image']) : '';
            return $instance;
        }
    }
}

add_action('wp_enqueue_scripts', 'enqueue_WiSu_About_script');
function enqueue_WiSu_About_script()
{
    wp_enqueue_style('wisu_about_style', get_template_directory_uri() . '/widgets/about/about.css', array('wisu-style'), null);
}

add_action('admin_enqueue_scripts', 'admin_enqueue_WiSu_About_script');
function admin_enqueue_WiSu_About_script()
{
    wp_enqueue_script('media-upload');
    wp_enqueue_media();
    wp_enqueue_script('wisu_about_admin', get_template_directory_uri() . '/widgets/about/admin.js', array('jquery'));
}